All of lore.kernel.org
 help / color / mirror / Atom feed
* [PATCH] GenWQE: Fix email address and update copyright notice
@ 2014-04-03  6:25 Frank Haverkamp
  2014-04-03 18:05 ` Greg KH
  0 siblings, 1 reply; 3+ messages in thread
From: Frank Haverkamp @ 2014-04-03  6:25 UTC (permalink / raw)
  To: gregkh; +Cc: linux-kernel, arnd, jsvogt, mijung, michael, esa, haver

Updated email address of co-author and updated the copyright notice
with the current year.

Signed-off-by: Frank Haverkamp <haver@linux.vnet.ibm.com>
Signed-off-by: Michael Jung <mijung@gmx.net>
---
 drivers/misc/genwqe/card_base.c         |    6 +++---
 drivers/misc/genwqe/card_base.h         |    4 ++--
 drivers/misc/genwqe/card_ddcb.c         |    4 ++--
 drivers/misc/genwqe/card_ddcb.h         |    4 ++--
 drivers/misc/genwqe/card_debugfs.c      |    4 ++--
 drivers/misc/genwqe/card_dev.c          |    4 ++--
 drivers/misc/genwqe/card_sysfs.c        |    4 ++--
 drivers/misc/genwqe/card_utils.c        |    4 ++--
 drivers/misc/genwqe/genwqe_driver.h     |    4 ++--
 include/uapi/linux/genwqe/genwqe_card.h |    4 ++--
 10 files changed, 21 insertions(+), 21 deletions(-)

--- a/drivers/misc/genwqe/card_base.h
+++ b/drivers/misc/genwqe/card_base.h
@@ -4,11 +4,11 @@
 /**
  * IBM Accelerator Family 'GenWQE'
  *
- * (C) Copyright IBM Corp. 2013
+ * (C) Copyright IBM Corp. 2013, 2014
  *
  * Author: Frank Haverkamp <haver@linux.vnet.ibm.com>
  * Author: Joerg-Stephan Vogt <jsvogt@de.ibm.com>
- * Author: Michael Jung <mijung@de.ibm.com>
+ * Author: Michael Jung <mijung@gmx.net>
  * Author: Michael Ruettger <michael@ibmra.de>
  *
  * This program is free software; you can redistribute it and/or modify
--- a/drivers/misc/genwqe/card_ddcb.c
+++ b/drivers/misc/genwqe/card_ddcb.c
@@ -1,11 +1,11 @@
 /**
  * IBM Accelerator Family 'GenWQE'
  *
- * (C) Copyright IBM Corp. 2013
+ * (C) Copyright IBM Corp. 2013, 2014
  *
  * Author: Frank Haverkamp <haver@linux.vnet.ibm.com>
  * Author: Joerg-Stephan Vogt <jsvogt@de.ibm.com>
- * Author: Michael Jung <mijung@de.ibm.com>
+ * Author: Michael Jung <mijung@gmx.net>
  * Author: Michael Ruettger <michael@ibmra.de>
  *
  * This program is free software; you can redistribute it and/or modify
--- a/drivers/misc/genwqe/card_ddcb.h
+++ b/drivers/misc/genwqe/card_ddcb.h
@@ -4,11 +4,11 @@
 /**
  * IBM Accelerator Family 'GenWQE'
  *
- * (C) Copyright IBM Corp. 2013
+ * (C) Copyright IBM Corp. 2013, 2014
  *
  * Author: Frank Haverkamp <haver@linux.vnet.ibm.com>
  * Author: Joerg-Stephan Vogt <jsvogt@de.ibm.com>
- * Author: Michael Jung <mijung@de.ibm.com>
+ * Author: Michael Jung <mijung@gmx.net>
  * Author: Michael Ruettger <michael@ibmra.de>
  *
  * This program is free software; you can redistribute it and/or modify
--- a/drivers/misc/genwqe/card_debugfs.c
+++ b/drivers/misc/genwqe/card_debugfs.c
@@ -1,11 +1,11 @@
 /**
  * IBM Accelerator Family 'GenWQE'
  *
- * (C) Copyright IBM Corp. 2013
+ * (C) Copyright IBM Corp. 2013, 2014
  *
  * Author: Frank Haverkamp <haver@linux.vnet.ibm.com>
  * Author: Joerg-Stephan Vogt <jsvogt@de.ibm.com>
- * Author: Michael Jung <mijung@de.ibm.com>
+ * Author: Michael Jung <mijung@gmx.net>
  * Author: Michael Ruettger <michael@ibmra.de>
  *
  * This program is free software; you can redistribute it and/or modify
--- a/drivers/misc/genwqe/card_dev.c
+++ b/drivers/misc/genwqe/card_dev.c
@@ -1,11 +1,11 @@
 /**
  * IBM Accelerator Family 'GenWQE'
  *
- * (C) Copyright IBM Corp. 2013
+ * (C) Copyright IBM Corp. 2013, 2014
  *
  * Author: Frank Haverkamp <haver@linux.vnet.ibm.com>
  * Author: Joerg-Stephan Vogt <jsvogt@de.ibm.com>
- * Author: Michael Jung <mijung@de.ibm.com>
+ * Author: Michael Jung <mijung@gmx.net>
  * Author: Michael Ruettger <michael@ibmra.de>
  *
  * This program is free software; you can redistribute it and/or modify
--- a/drivers/misc/genwqe/card_sysfs.c
+++ b/drivers/misc/genwqe/card_sysfs.c
@@ -1,11 +1,11 @@
 /**
  * IBM Accelerator Family 'GenWQE'
  *
- * (C) Copyright IBM Corp. 2013
+ * (C) Copyright IBM Corp. 2013, 2014
  *
  * Author: Frank Haverkamp <haver@linux.vnet.ibm.com>
  * Author: Joerg-Stephan Vogt <jsvogt@de.ibm.com>
- * Author: Michael Jung <mijung@de.ibm.com>
+ * Author: Michael Jung <mijung@gmx.net>
  * Author: Michael Ruettger <michael@ibmra.de>
  *
  * This program is free software; you can redistribute it and/or modify
--- a/drivers/misc/genwqe/card_utils.c
+++ b/drivers/misc/genwqe/card_utils.c
@@ -1,11 +1,11 @@
 /**
  * IBM Accelerator Family 'GenWQE'
  *
- * (C) Copyright IBM Corp. 2013
+ * (C) Copyright IBM Corp. 2013, 2014
  *
  * Author: Frank Haverkamp <haver@linux.vnet.ibm.com>
  * Author: Joerg-Stephan Vogt <jsvogt@de.ibm.com>
- * Author: Michael Jung <mijung@de.ibm.com>
+ * Author: Michael Jung <mijung@gmx.net>
  * Author: Michael Ruettger <michael@ibmra.de>
  *
  * This program is free software; you can redistribute it and/or modify
--- a/drivers/misc/genwqe/genwqe_driver.h
+++ b/drivers/misc/genwqe/genwqe_driver.h
@@ -4,11 +4,11 @@
 /**
  * IBM Accelerator Family 'GenWQE'
  *
- * (C) Copyright IBM Corp. 2013
+ * (C) Copyright IBM Corp. 2013, 2014
  *
  * Author: Frank Haverkamp <haver@linux.vnet.ibm.com>
  * Author: Joerg-Stephan Vogt <jsvogt@de.ibm.com>
- * Author: Michael Jung <mijung@de.ibm.com>
+ * Author: Michael Jung <mijung@gmx.net>
  * Author: Michael Ruettger <michael@ibmra.de>
  *
  * This program is free software; you can redistribute it and/or modify
--- a/include/uapi/linux/genwqe/genwqe_card.h
+++ b/include/uapi/linux/genwqe/genwqe_card.h
@@ -4,11 +4,11 @@
 /**
  * IBM Accelerator Family 'GenWQE'
  *
- * (C) Copyright IBM Corp. 2013
+ * (C) Copyright IBM Corp. 2013, 2014
  *
  * Author: Frank Haverkamp <haver@linux.vnet.ibm.com>
  * Author: Joerg-Stephan Vogt <jsvogt@de.ibm.com>
- * Author: Michael Jung <mijung@de.ibm.com>
+ * Author: Michael Jung <mijung@gmx.net>
  * Author: Michael Ruettger <michael@ibmra.de>
  *
  * This program is free software; you can redistribute it and/or modify


^ permalink raw reply	[flat|nested] 3+ messages in thread

* Re: [PATCH] GenWQE: Fix email address and update copyright notice
  2014-04-03  6:25 [PATCH] GenWQE: Fix email address and update copyright notice Frank Haverkamp
@ 2014-04-03 18:05 ` Greg KH
  2014-04-07 13:52   ` Frank Haverkamp
  0 siblings, 1 reply; 3+ messages in thread
From: Greg KH @ 2014-04-03 18:05 UTC (permalink / raw)
  To: Frank Haverkamp; +Cc: linux-kernel, arnd, jsvogt, mijung, michael, esa

On Thu, Apr 03, 2014 at 08:25:27AM +0200, Frank Haverkamp wrote:
> Updated email address of co-author and updated the copyright notice
> with the current year.

Why update the copyright notice, it doesn't mean anything, as IBM
lawyers know well, so who is asking for this change?

thanks,

greg k-h

^ permalink raw reply	[flat|nested] 3+ messages in thread

* Re: [PATCH] GenWQE: Fix email address and update copyright notice
  2014-04-03 18:05 ` Greg KH
@ 2014-04-07 13:52   ` Frank Haverkamp
  0 siblings, 0 replies; 3+ messages in thread
From: Frank Haverkamp @ 2014-04-07 13:52 UTC (permalink / raw)
  To: Greg KH; +Cc: linux-kernel, arnd, jsvogt, mijung, michael, esa

Hi Greg,

Am Donnerstag, den 03.04.2014, 11:05 -0700 schrieb Greg KH:
> On Thu, Apr 03, 2014 at 08:25:27AM +0200, Frank Haverkamp wrote:
> > Updated email address of co-author and updated the copyright notice
> > with the current year.
> 
> Why update the copyright notice, it doesn't mean anything, as IBM
> lawyers know well, so who is asking for this change?
> 

I thought it would be a good idea to update it, to keep it up to date.
If you don't like my addition of the year in the copyright notice, I can
remove it. Just let me know. I think it is not such important.

The other content of this patch is, as you have seen, a spelling error
in the name of my team member and that he wanted to have a different
email address in the code.


> thanks,
> 
> greg k-h
> 

Regards

Frank



^ permalink raw reply	[flat|nested] 3+ messages in thread

end of thread, other threads:[~2014-04-07 13:52 UTC | newest]

Thread overview: 3+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2014-04-03  6:25 [PATCH] GenWQE: Fix email address and update copyright notice Frank Haverkamp
2014-04-03 18:05 ` Greg KH
2014-04-07 13:52   ` Frank Haverkamp

This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.
--- a/drivers/misc/genwqe/card_base.c
+++ b/drivers/misc/genwqe/card_base.c
@@ -1,11 +1,11 @@
 /**
  * IBM Accelerator Family 'GenWQE'
  *
- * (C) Copyright IBM Corp. 2013
+ * (C) Copyright IBM Corp. 2013, 2014
  *
  * Author: Frank Haverkamp <haver@linux.vnet.ibm.com>
  * Author: Joerg-Stephan Vogt <jsvogt@de.ibm.com>
  * Author: Michael Jung <mijung@de.ibm.com>
  * Author: Michael Ruettger <michael@ibmra.de>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -46,7 +46,7 @@
 MODULE_AUTHOR("Frank Haverkamp <haver@linux.vnet.ibm.com>");
 MODULE_AUTHOR("Michael Ruettger <michael@ibmra.de>");
 MODULE_AUTHOR("Joerg-Stephan Vogt <jsvogt@de.ibm.com>");
-MODULE_AUTHOR("Michal Jung <mijung@de.ibm.com>");
+MODULE_AUTHOR("Michael Jung <mijung@gmx.net>");
 
 MODULE_DESCRIPTION("GenWQE Card");
 MODULE_VERSION(DRV_VERS_STRING);
@@ -1,11 +1,11 @@
  * Author: Frank Haverkamp <haver@linux.vnet.ibm.com>
  * Author: Joerg-Stephan Vogt <jsvogt@de.ibm.com>
- * Author: Michael Jung <mijung@de.ibm.com>
+ * Author: Michael Jung <mijung@gmx.net>
  * Author: Michael Ruettger <michael@ibmra.de>
  *